@@ -1,7 +1,5 @@
-
-
-#ifndef EC_RESOLV_H
-#define EC_RESOLV_H
+#ifndef ETTERCAP_RESOLV_H
+#define ETTERCAP_RESOLV_H
 
 #include <ec_inet.h>
 
@@ -44,7 +42,7 @@
 EC_API_EXTERN int host_iptoa(struct ip_addr *ip, char *name);
 
 /* used by ec_dns to insert passively sniffed dns answers */
-EC_API_EXTERN void resolv_cache_insert(struct ip_addr *ip, char *name);
+EC_API_EXTERN void resolv_cache_insert_passive(struct ip_addr *ip, char *name);
    
 
    
