@@ -1,7 +1,5 @@
-
-
-#ifndef EC_STDINT_H
-#define EC_STDINT_H
+#ifndef ETTERCAP_STDINT_H
+#define ETTERCAP_STDINT_H
 
 #include <limits.h>
 
@@ -13,6 +11,22 @@
 	#include <sys/inttypes.h>
 #endif
 
+#if defined HAVE_INTTYPES_H
+	#include <inttypes.h>
+#else /* HAVE_INTTYPES_H */
+	#if __WORDSIZE == 64
+		#define __PRI64_PREFIX "l"
+	#else
+		#define __PRI64_PREFIX "ll"
+	#endif
+#ifndef PRId64
+	#define PRId64 __PRI64_PREFIX "d"
+#endif
+#ifndef PRIu64
+	#define PRIu64 __PRI64_PREFIX "u"
+#endif
+#endif /* HAVE_INTTYPES_H */
+
 #ifndef TYPES_DEFINED
 #define TYPES_DEFINED
 	typedef int8_t    int8;
