@@ -1,7 +1,5 @@
-
-
-#ifndef EC_UI_H
-#define EC_UI_H
+#ifndef ETTERCAP_UI_H
+#define ETTERCAP_UI_H
 
 #include <stdarg.h>
 
@@ -19,6 +17,7 @@ struct ui_ops {
       #define UI_PROGRESS_UPDATED      1
    void (*update)(int);
       #define UI_UPDATE_HOSTLIST       1
+      #define UI_UPDATE_PLUGINLIST     2
    char initialized;
    char type;
       #define UI_TEXT      0
@@ -46,7 +45,7 @@ EC_API_EXTERN void ui_register(struct ui_ops *ops);
 
 #define INSTANT_USER_MSG(x, ...) do { ui_msg(x, ## __VA_ARGS__ ); ui_msg_flush(MSG_ALL); } while(0)
 
-#define FATAL_MSG(x, ...) do { ui_error(x, ## __VA_ARGS__ ); return (-EFATAL); } while(0)
+#define FATAL_MSG(x, ...) do { ui_error(x, ## __VA_ARGS__ ); return (-E_FATAL); } while(0)
 
 /* 
  * if we are using the text interface, exit with a fatal error,
