@@ -1,7 +1,5 @@
-
-
-#ifndef EC_UPDATE_H
-#define EC_UPDATE_H
+#ifndef ETTERCAP_UPDATE_H
+#define ETTERCAP_UPDATE_H
 
 EC_API_EXTERN void global_update(void);
 
