@@ -2,6 +2,6 @@
 #error Move this header somewhere else
 #endif
 
-EC_API_EXTERN char * strcasestr(char *hailstack, char *needle);
+EC_API_EXTERN char * strcasestr(const char *hailstack, const char *needle);
 
 /* EOF */
