@@ -84,6 +84,9 @@ int plugin_load(void *handle)
 
 static int pptp_clear_init(void *dummy) 
 {
+   /* variable not used */
+   (void) dummy;
+
    /* It doesn't work if unoffensive */
    if (GBL_OPTIONS->unoffensive) {
       INSTANT_USER_MSG("pptp_clear: plugin doesn't work in UNOFFENSIVE mode\n");
@@ -101,6 +104,9 @@ static int pptp_clear_init(void *dummy)
 
 static int pptp_clear_fini(void *dummy) 
 {
+   /* variable not used */
+   (void) dummy;
+
    USER_MSG("pptp_clear: plugin terminated...\n");
 
    hook_del(HOOK_PACKET_LCP, &parse_lcp);
