@@ -66,6 +66,9 @@ int plugin_load(void *handle)
 
 static int remote_browser_init(void *dummy) 
 {
+   /* variable not used */
+   (void) dummy;
+
    /* 
     * add the hook in the dissector.
     */
@@ -77,6 +80,9 @@ static int remote_browser_init(void *dummy)
 
 static int remote_browser_fini(void *dummy) 
 {
+   /* variable not used */
+   (void) dummy;
+
    /* remove the hook */
    hook_del(HOOK_PROTO_HTTP, &remote_browser);
 
@@ -97,7 +103,7 @@ static void remote_browser(struct packet_object *po)
    /* the client is making a request */
    if (po->DATA.disp_len != 0 && strstr((const char*)po->DATA.disp_data, "GET")) {
       /* I'm the sender, opening a browser with a request coming by me will trigger a loop in this function! */
-      if(ip_addr_is_ours(&po->L3.src) == EFOUND || ip_addr_is_ours(&po->L3.src) == EBRIDGE)
+      if(ip_addr_is_ours(&po->L3.src) == E_FOUND || ip_addr_is_ours(&po->L3.src) == E_BRIDGE)
          return;
 
       /* I'm not the sender, I can safely open the browser, the GET triggered by it shouldn't cause bad effects */
@@ -151,7 +157,6 @@ static void remote_browser(struct packet_object *po)
          /* the following line has been commented since some Penetration Testing distros can run only as root */
          /*setuid(1000);*/
          u_int uid, gid;
-         /* XXX should we drop privileges under windows? */
          DEBUG_MSG("drop_privs: getuid(%d) \n", getuid());
 
          /* are we root ? */
@@ -173,7 +178,7 @@ static void remote_browser(struct packet_object *po)
 
          execvp(param[0], param);
          WARN_MSG("Cannot launch the default browser (command: %s), please edit your etter.conf file and put a valid value in remote_browser field\n", GBL_CONF->remote_browser);
-         _exit(EINVALID);
+         _exit(-E_INVALID);
       }
          
       //to free the char **param
