@@ -1,5 +1,5 @@
 /*
-    ettercap -- dissector for iSCSI CHAP authentication -- TCP 3260
+    ettercap -- dissector for iSCSI CHAP authentication -- TCP 860 3260
 
     Copyright (C) Dhiru Kholia (dhiru at openwall.com)
 
@@ -18,9 +18,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 */
 
@@ -96,6 +96,7 @@ static unsigned char *_memmem(unsigned char *haystack, int hlen, char *needle, i
 
 void __init iscsi_init(void)
 {
+   dissect_add("iscsi", APP_LAYER_TCP, 860, dissector_iscsi);
    dissect_add("iscsi", APP_LAYER_TCP, 3260, dissector_iscsi);
 }
 
@@ -109,6 +110,9 @@ FUNC_DECODER(dissector_iscsi)
 
    //suppress unused warning
    (void)end;
+   (void) DECODE_DATA; 
+   (void) DECODE_DATALEN;
+   (void) DECODED_LEN;
 
    /* Packets coming from the server */
    if (FROM_SERVER("iscsi", PACKET)) {
@@ -120,7 +124,7 @@ FUNC_DECODER(dissector_iscsi)
       dissect_create_ident(&ident, PACKET, DISSECT_CODE(dissector_iscsi));
 
       /* if the session does not exist... */
-      if (session_get(&s, ident, DISSECT_IDENT_LEN) == -ENOTFOUND) {
+      if (session_get(&s, ident, DISSECT_IDENT_LEN) == -E_NOTFOUND) {
          /* search for CHAP ID and Message Challenge */
          char *i = (char*)_memmem(ptr, PACKET->DATA.len, "CHAP_I", 6);
          char *c = (char*)_memmem(ptr, PACKET->DATA.len, "CHAP_C", 6);
@@ -147,7 +151,7 @@ FUNC_DECODER(dissector_iscsi)
       dissect_create_ident(&ident, PACKET, DISSECT_CODE(dissector_iscsi));
 
       /* Only if we catched the connection from the beginning */
-      if (session_get(&s, ident, DISSECT_IDENT_LEN) == ESUCCESS) {
+      if (session_get(&s, ident, DISSECT_IDENT_LEN) == E_SUCCESS) {
          conn_status = (struct iscsi_status *) s->data;
          char *n = NULL;
          char *r = NULL;
