@@ -18,9 +18,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 */
 
@@ -66,6 +66,9 @@ FUNC_DECODER(dissector_o5logon)
 
    //suppress unused warning
    (void)end;
+   (void) DECODE_DATA;
+   (void) DECODE_DATALEN;
+   (void) DECODED_LEN;
 
    if (FROM_CLIENT("o5logon", PACKET)) {
 
@@ -75,7 +78,7 @@ FUNC_DECODER(dissector_o5logon)
 
       dissect_create_ident(&ident, PACKET, DISSECT_CODE(dissector_o5logon));
       /* if the session does not exist... */
-      if (session_get(&s, ident, DISSECT_IDENT_LEN) == -ENOTFOUND) {
+      if (session_get(&s, ident, DISSECT_IDENT_LEN) == -E_NOTFOUND) {
          unsigned char *skp  = memmem(ptr, PACKET->DATA.len, "AUTH_SESSKEY", 12);
          unsigned char *sp = memmem(ptr, PACKET->DATA.len, "AUTH_TERMINAL", 13);
          if (sp && !skp) {
@@ -96,7 +99,7 @@ FUNC_DECODER(dissector_o5logon)
               }
               last--;
             }
-            int length = *(last+1);
+            unsigned int length = *(last+1);
             if (length < sizeof(conn_status->user))
             {
                strncpy((char*)conn_status->user, (char*)last + 2, length);
@@ -107,10 +110,25 @@ FUNC_DECODER(dissector_o5logon)
             session_put(s);
          }
       }
+      else {
+         /* try to deal with stealth mode scans in which client stops talking
+          * after receiving AUTH_VFR_DATA */
+         conn_status = (struct o5logon_status *) s->data;
+         if (conn_status->status == WAIT_RESULT) {
+            /* is client trying to continue the authentication dance? */
+            unsigned char *cont = NULL;
+            if (PACKET->DATA.len > 12) {
+               cont = memmem(ptr, PACKET->DATA.len, "AUTH_SESSKEY", 12);
+            }
+            if (!cont) { /* seems like a fresh authentication attempt */
+               dissect_wipe_session(PACKET, DISSECT_CODE(dissector_o5logon));
+            }
+         }
+      }
    } else {
       dissect_create_ident(&ident, PACKET, DISSECT_CODE(dissector_o5logon));
 
-      if (session_get(&s, ident, DISSECT_IDENT_LEN) == ESUCCESS) {
+      if (session_get(&s, ident, DISSECT_IDENT_LEN) == E_SUCCESS) {
          conn_status = (struct o5logon_status *) s->data;
          unsigned char *skp  = NULL;
          unsigned char *saltp = NULL;
