@@ -23,7 +23,7 @@
 #include <ec_threads.h>
 #include <ec_hook.h>
 #include <ec_stats.h>
-#include <time.h>
+#include <ec_sleep.h>
 
 
 /* this is the PO queue from bottom to top half */
@@ -61,11 +61,8 @@ EC_THREAD_FUNC(top_half)
    struct po_queue_entry *e;
    u_int pck_len;
  
-#if !defined(OS_WINDOWS) 
-   struct timespec tm;   
-   tm.tv_sec = 0;
-   tm.tv_nsec = 1000; 
-#endif
+   /* variable not used */
+   (void) EC_THREAD_PARAM;
 
    /* initialize the thread */
    ec_thread_init();
@@ -97,11 +94,7 @@ EC_THREAD_FUNC(top_half)
       /* the queue is empty, nothing to do... */
       if (e == NULL) {
          PO_QUEUE_UNLOCK;
-#if !defined(OS_WINDOWS)         
-         nanosleep(&tm, NULL);
-#else
-         usleep(100);
-#endif
+         ec_usleep(1); // 1µs
          continue;
       }
   
