@@ -38,21 +38,11 @@ static pthread_mutex_t root_mutex = PTHREAD_MUTEX_INITIALIZER;
 
 /* protos */
 
-int wifi_key_prepare(char *key_string);
-
-int wep_decrypt(u_char *buf, size_t len, u_char *wkey, size_t wlen);
 static int set_wep_key(char *string);
 static void make_key_64(u_char *string, u_char *key);
 static void make_key_128(u_char *string, u_char *key);
 
 static int set_wpa_key(char *string);
-void wpa_sess_add(u_char *sta, struct wpa_sa *sa);
-void wpa_sess_del(u_char *sta);
-int wpa_sess_get(u_char *sta, struct wpa_sa *sa);
-int wpa_generate_PTK(u_char *bssid, u_char *sta, u_char *pmk, u_char *snonce, u_char *anonce,u_int16 bits, u_char *kck);
-int wpa_check_MIC(struct eapol_header *eapol, struct eapol_key_header* eapol_key, size_t eapol_len, u_char *kck, int algo);
-int wpa_decrypt_broadcast_key(struct eapol_key_header *eapol_key, struct rsn_ie_header *rsn_ie, struct wpa_sa *sa);
-int wpa_decrypt(u_char *mac, u_char *data, size_t len, struct wpa_sa sa);
 extern int wpa_ccmp_decrypt(u_char *mac, u_char *data, size_t len, struct wpa_sa sa);
 extern int wpa_tkip_decrypt(u_char *mac, u_char *data, size_t len, struct wpa_sa sa);
 
@@ -71,7 +61,7 @@ int wep_decrypt(u_char *buf, size_t len, u_char *wkey, size_t wlen)
 
    /* the key was not set, don't try to decript it */
    if (wlen == 0)
-      return -ENOTHANDLED;
+      return -E_NOTHANDLED;
 
    /* get the wep header */
    wep = (struct wep_header *)buf;
@@ -83,7 +73,7 @@ int wep_decrypt(u_char *buf, size_t len, u_char *wkey, size_t wlen)
    /* sanity check on the key index */
    if (wep->key * 5 > (int)(MAX_WKEY_LEN - wlen)) {
       //DEBUG_MSG(D_VERBOSE, "WEP: invalid key index, the packet was skipped");
-      return -ENOTHANDLED;
+      return -E_NOTHANDLED;
    }
 
    encbuf = (u_char *)(wep + 1);
@@ -112,7 +102,7 @@ int wep_decrypt(u_char *buf, size_t len, u_char *wkey, size_t wlen)
     */
    if (CRC_checksum(decbuf, len + WEP_CRC_LEN, CRC_INIT) != CRC_RESULT) {
       //DEBUG_MSG(D_VERBOSE, "WEP decryption failed, the packet was skipped");
-      return -ENOTHANDLED;
+      return -E_NOTHANDLED;
    }
 
    /*
@@ -129,7 +119,7 @@ int wep_decrypt(u_char *buf, size_t len, u_char *wkey, size_t wlen)
     */
    memset(buf + len, 0, WEP_CRC_LEN);
 
-   return ESUCCESS;
+   return E_SUCCESS;
 }
 
 /*
@@ -153,12 +143,12 @@ int wep_decrypt(u_char *buf, size_t len, u_char *wkey, size_t wlen)
 
 int wifi_key_prepare(char *key_string)
 {
-   int status = -EINVALID;
+   int status = -E_INVALID;
    char *ks;
    char *p;
 
    if (key_string == NULL)
-      return -EINVALID;
+      return -E_INVALID;
 
    ks = strdup(key_string);
 
@@ -205,14 +195,14 @@ int set_wep_key(char *string)
 
    /* sanity check */
    if (bit <= 0)
-      SEMIFATAL_ERROR("Unsupported WEP key lenght");
+      SEMIFATAL_ERROR("Unsupported WEP key length");
 
    /* the len of the secret part of the RC4 seed */
    tmp_wkey_len = bit / 8 - WEP_IV_LEN;
 
    /* sanity check */
    if (bit != 64 && bit != 128)
-	  SEMIFATAL_ERROR("Unsupported WEP key lenght");
+	  SEMIFATAL_ERROR("Unsupported WEP key length");
 
    /* get the type of the key */
    p = ec_strtok(NULL, ":", &tok);
@@ -227,7 +217,7 @@ int set_wep_key(char *string)
 	  SEMIFATAL_ERROR("Invalid parsing of the WEP key");
 
    if (type == 's') {
-      /* escape the string and check its lenght */
+      /* escape the string and check its length */
       if (strescape((char *)tmp_wkey, p) != (int)tmp_wkey_len)
     	  SEMIFATAL_ERROR("Specified WEP key length does not match the given string");
    } else if (type == 'p') {
@@ -247,7 +237,7 @@ int set_wep_key(char *string)
    memcpy(GBL_WIFI->wkey, tmp_wkey, sizeof(GBL_WIFI->wkey));
    GBL_WIFI->wkey_len = tmp_wkey_len;
 
-   return ESUCCESS;
+   return E_SUCCESS;
 }
 
 /*
@@ -352,7 +342,7 @@ static int set_wpa_key(char *string)
    /* print the final string */
    USER_MSG("Using WPA key: %s\n", str_tohex(GBL_WIFI->wkey, WPA_KEY_LEN, tmp, sizeof(tmp)));
 
-   return ESUCCESS;
+   return E_SUCCESS;
 }
 
 
@@ -431,12 +421,12 @@ int wpa_sess_get(u_char *sta, struct wpa_sa *sa)
       if (!memcmp(&e->sta, sta, ETH_ADDR_LEN)) {
          memcpy(sa, &e->sa, sizeof(struct wpa_sa));
          pthread_mutex_unlock(&root_mutex);
-         return ESUCCESS;
+         return E_SUCCESS;
       }
    }
    pthread_mutex_unlock(&root_mutex);
 
-   return -ENOTFOUND;
+   return -E_NOTFOUND;
 }
 
 /* Function used to derive the PTK. Refer to IEEE 802.11I-2004, 8.5.1 */
@@ -488,7 +478,7 @@ int wpa_generate_PTK(u_char *bssid, u_char *sta, u_char *pmk, u_char *snonce, u_
        HMAC(EVP_sha1(), pmk, WPA_KEY_LEN, buff, 100, kck + i * 20, &len);
    }
 
-   return ESUCCESS;
+   return E_SUCCESS;
 }
 
 
@@ -512,7 +502,7 @@ int wpa_check_MIC(struct eapol_header *eapol, struct eapol_key_header* eapol_key
        HMAC(EVP_sha1(), kck, WPA_KCK_LEN, (u_char *)eapol, eapol_len, hmac_mic, &len);
    } else
        /* key descriptor version not recognized */
-       return -EINVALID;
+       return -E_INVALID;
 
    /* restore the MIC in the EAPOL packet */
    memcpy(eapol_key->key_MIC, mic, WPA_MICKEY_LEN);
@@ -529,7 +519,10 @@ int wpa_decrypt_broadcast_key(struct eapol_key_header *eapol_key, struct rsn_ie_
    u_int16 key_len = 0;
    //static AIRPDCAP_KEY_ITEM dummy_key; /* needed in case AirPDcapRsnaMng() wants the key structure */
 
-char tmp[512];
+   char tmp[512];
+
+   /* variable not used */
+   (void) rsn_ie;
 
    /* Preparation for decrypting the group key - determine group key data length */
    /* depending on whether it's a TKIP or AES encryption key */
@@ -541,14 +534,14 @@ char tmp[512];
 
    /* sanity check */
    if (key_len > sizeof(struct rsn_ie_header) || key_len == 0)
-      return -ENOTHANDLED;
+      return -E_NOTHANDLED;
 
    /* Encrypted key is in the information element field of the EAPOL key packet */
    SAFE_CALLOC(encrypted_key, key_len, sizeof(u_int8));
 
-   DEBUG_MSG("Encrypted Broadcast key:", str_tohex(encrypted_key, key_len, tmp, sizeof(tmp)));
-   DEBUG_MSG("KeyIV:", str_tohex(eapol_key->key_IV, 16, tmp, sizeof(tmp)));
-   DEBUG_MSG("decryption_key:", str_tohex(sa->ptk + 16, 16, tmp, sizeof(tmp)));
+   DEBUG_MSG("Encrypted Broadcast key: %s\n", str_tohex(encrypted_key, key_len, tmp, sizeof(tmp)));
+   DEBUG_MSG("KeyIV: %s\n", str_tohex(eapol_key->key_IV, 16, tmp, sizeof(tmp)));
+   DEBUG_MSG("decryption_key: %s\n", str_tohex(sa->ptk + 16, 16, tmp, sizeof(tmp)));
 
    /*
     * XXX - implement broadcast key
@@ -629,7 +622,7 @@ char tmp[512];
 
    SAFE_FREE(encrypted_key);
 
-   return ESUCCESS;
+   return E_SUCCESS;
 }
 
 
@@ -647,7 +640,7 @@ int wpa_decrypt(u_char *mac, u_char *data, size_t len, struct wpa_sa sa)
    }
 
    /* not reached */
-   return -ENOTHANDLED;
+   return -E_NOTHANDLED;
 }
 
 /* EOF */
