@@ -23,6 +23,7 @@
 #include <ec_mitm.h>
 #include <ec_poll.h>
 #include <ec_scan.h>
+#include <ec_sleep.h>
 
 /* globals */
 
@@ -38,15 +39,6 @@ struct mitm_entry {
 
 static char *mitm_args = "";
 
-/* protos */
-
-void mitm_add(struct mitm_method *mm);
-int mitm_set(char *name);
-int mitm_start(void);
-void mitm_stop(void);
-void only_mitm(void);
-int is_mitm_active(char *name);
-
 /*******************************************/
 
 /*
@@ -89,11 +81,11 @@ int mitm_set(char *name)
    SLIST_FOREACH(e, &mitm_table, next) {
       if (!strcasecmp(e->mm->name, name)) {
          e->selected = 1;
-         return ESUCCESS;
+         return E_SUCCESS;
       }
    }
 
-   return -ENOTFOUND;
+   return -E_NOTFOUND;
 }
 
 /*
@@ -122,7 +114,7 @@ int mitm_start(void)
    /* reading from file we won't start mitm */
    if (GBL_OPTIONS->read || GBL_OPTIONS->unoffensive) {
       DEBUG_MSG("mitm_start: skipping");
-      return -EINVALID;
+      return -E_INVALID;
    }
 
       
@@ -145,14 +137,14 @@ int mitm_start(void)
           * if the mitm method does not start correctly,
           * deselect it !
           */
-         if (e->mm->start(mitm_args) == ESUCCESS)
+         if (e->mm->start(mitm_args) == E_SUCCESS)
             e->started = 1;
          else
             e->selected = 0;
       }
    }
 
-   return ESUCCESS;
+   return E_SUCCESS;
 }
 
 
@@ -195,7 +187,7 @@ void only_mitm(void)
 
    if (GBL_UI->type == UI_DAEMONIZE)
        LOOP {
-           sleep(1);
+           ec_usleep(SEC2MICRO(1));
        }
   
    /* wait for user to exit */
