@@ -26,13 +26,38 @@
 #include <ec_decode.h>
 #include <ec_resolv.h>
 #include <ec_file.h>
+#include <ec_sleep.h>
+#include <ec_capture.h>
 
 #include <pthread.h>
 #include <pcap.h>
 #include <libnet.h>
-#include <time.h>
 
 /* globals */
+static pthread_mutex_t scan_mutex = PTHREAD_MUTEX_INITIALIZER;
+/*
+ * SCAN_{LOCK,UNLOCK} and SCANUI_{LOCK,UNLOCK} are two macros
+ * that handles the SAME mutex "scan_mutex".
+ * They are intended to cancel threads that are not getting
+ * the lock (Pressing Crtl+S multiple times while scanning).
+ * They are split because the lock is used in different functions
+ * of different types (void/void*).
+ */
+#define SCAN_LOCK do{ if (pthread_mutex_trylock(&scan_mutex)) { \
+ ec_thread_exit(); return NULL;} \
+ } while(0)
+#define SCAN_UNLOCK do{ pthread_mutex_unlock(&scan_mutex); } while(0)
+
+#define SCANUI_LOCK do{ if (pthread_mutex_trylock(&scan_mutex)) { \
+ return; } \
+ } while (0)
+
+#define SCANUI_UNLOCK SCAN_UNLOCK
+
+#define EC_CHECK_LIBNET_VERSION(major,minor)   \
+   (LIBNET_VERSION_MAJOR > (major) ||          \
+    (LIBNET_VERSION_MAJOR == (major) && LIBNET_VERSION_MINOR >= (minor)))
+
 
 /* used to create the random list */
 static LIST_HEAD (, ip_list) ip_list_head;
@@ -43,8 +68,11 @@ static struct ip_list **rand_array;
 void build_hosts_list(void);
 void del_hosts_list(void);
 
-static void scan_netmask(pthread_t pid);
-static void scan_targets(pthread_t pid);
+static void scan_netmask();
+#ifdef WITH_IPV6
+static void scan_ip6_onlink();
+#endif
+static void scan_targets();
 
 int scan_load_hosts(char *filename);
 int scan_save_hosts(char *filename);
@@ -54,9 +82,7 @@ void add_host(struct ip_addr *ip, u_int8 mac[MEDIA_ADDR_LEN], char *name);
 static void random_list(struct ip_list *e, int max);
 
 static void get_response(struct packet_object *po);
-static EC_THREAD_FUNC(capture_scan);
 static EC_THREAD_FUNC(scan_thread);
-static void scan_decode(u_char *param, const struct pcap_pkthdr *pkthdr, const u_char *pkt);
 
 void __init hook_init(void);
 static void hosts_list_hook(struct packet_object *po);
@@ -110,20 +136,13 @@ void build_hosts_list(void)
    /* delete the previous list */
    del_hosts_list();
 
-#ifdef OS_MINGW
-   /* FIXME: for some reason under windows it does not work in thread mode
-    * to be investigated...
-    */
-	scan_thread(NULL);
-#else
    /* check the type of UI we are running under... */
-   if (GBL_UI->type == UI_TEXT || GBL_UI->type == UI_DAEMONIZE || GBL_UI->type == UI_CURSES)
-      /* in text mode and demonized call the function directly */
+   if (GBL_UI->type == UI_TEXT || GBL_UI->type == UI_DAEMONIZE)
+      /* in text mode and daemonized call the function directly */
       scan_thread(NULL);
    else 
       /* do the scan in a separate thread */
       ec_thread_new("scan", "scanning thread", &scan_thread, NULL);
-#endif
 }
 
 /*
@@ -131,20 +150,18 @@ void build_hosts_list(void)
  */
 static EC_THREAD_FUNC(scan_thread)
 {
-   pthread_t pid;
    struct hosts_list *hl;
-   struct timespec ts;
    int i = 1, ret;
    int nhosts = 0;
    int threadize = 1;
 
+   /* variable not used */
+   (void) EC_THREAD_PARAM;
+
    DEBUG_MSG("scan_thread");
 
-   ts.tv_sec = 1;
-   ts.tv_nsec = 0;
-
    /* in text mode and demonized this function should NOT be a thread */
-   if (GBL_UI->type == UI_TEXT || GBL_UI->type == UI_DAEMONIZE || GBL_UI->type == UI_CURSES)
+   if (GBL_UI->type == UI_TEXT || GBL_UI->type == UI_DAEMONIZE)
       threadize = 0;
 
 #ifdef OS_MINGW
@@ -158,14 +175,24 @@ static EC_THREAD_FUNC(scan_thread)
    if (threadize)
       ec_thread_init();
 
+   /* Only one thread is allowed to scan at a time */
+   SCAN_LOCK;
+
+   /* if sniffing is not yet started we need a decoder for the ARP/ND replies */
+   if (!GBL_SNIFF->active)
+      capture_start(GBL_IFACE);
+
    /*
     * create a simple decode thread, it will call
     * the right HOOK POINT. so we only have to hook to
     * ARP packets.
     */
    hook_add(HOOK_PACKET_ARP_RP, &get_response);
+#ifdef WITH_IPV6
    hook_add(HOOK_PACKET_ICMP6_NADV, &get_response);
-   pid = ec_thread_new("scan_cap", "decoder module while scanning", &capture_scan, NULL);
+   hook_add(HOOK_PACKET_ICMP6_RPLY, &get_response);
+   hook_add(HOOK_PACKET_ICMP6_PARM, &get_response);
+#endif
 
    /*
     * if at least one ip target is ANY, scan the whole netmask
@@ -176,9 +203,13 @@ static EC_THREAD_FUNC(scan_thread)
     * FIXME: ipv4 host gets scanned twice if in target list
     */
    if(GBL_TARGET1->all_ip || GBL_TARGET2->all_ip) {
-      scan_netmask(pid);
+      scan_netmask();
+#ifdef WITH_IPV6
+      if (GBL_OPTIONS->ip6scan) 
+          scan_ip6_onlink();
+#endif
    }
-   scan_targets(pid);
+   scan_targets();
 
    /*
     * free the temporary array for random computations
@@ -187,20 +218,25 @@ static EC_THREAD_FUNC(scan_thread)
    SAFE_FREE(rand_array);
 
    /*
-    * wait for some delayed packets...
+    * wait a second for some delayed packets...
     * the other thread is listening for ARP pachets
     */
+   ec_usleep(SEC2MICRO(1));
 
-#if defined(OS_WINDOWS)
-   usleep(1000); //1 msec
-#else
-   nanosleep(&ts, NULL);
+   /* remove the hooks for parsing the ARP/ND packets during scan */
+   hook_del(HOOK_PACKET_ARP, &get_response);
+#ifdef WITH_IPV6
+   hook_del(HOOK_PACKET_ICMP6_NADV, &get_response);
+   hook_del(HOOK_PACKET_ICMP6_RPLY, &get_response);
+   hook_del(HOOK_PACKET_ICMP6_PARM, &get_response);
 #endif
 
-   /* destroy the thread and remove the hook function */
-   ec_thread_destroy(pid);
-   hook_del(HOOK_PACKET_ARP, &get_response);
-   hook_del(HOOK_PACKET_ICMP6_NADV, &get_response);
+   /* if sniffing is not started we have to stop the decoder after scan */
+   if (!GBL_SNIFF->active)
+      capture_stop(GBL_IFACE);
+
+   /* Unlock Mutex */
+   SCAN_UNLOCK;
 
    /* count the hosts and print the message */
    LIST_FOREACH(hl, &GBL_HOSTLIST, next) {
@@ -264,81 +300,26 @@ void del_hosts_list(void)
 {
    struct hosts_list *hl, *tmp = NULL;
 
+   SCANUI_LOCK;
+
    LIST_FOREACH_SAFE(hl, &GBL_HOSTLIST, next, tmp) {
       SAFE_FREE(hl->hostname);
       LIST_REMOVE(hl, next);
       SAFE_FREE(hl);
    }
+
+   SCANUI_UNLOCK;
 }
 
-
 /*
- * capture the packets and call the HOOK POINT
- */
-static EC_THREAD_FUNC(capture_scan)
-{
-   DEBUG_MSG("capture_scan");
-
-   ec_thread_init();
-
-   pcap_loop(GBL_IFACE->pcap, -1, scan_decode, EC_THREAD_PARAM);
-
-   return NULL;
-}
-
-
-/*
- * parses the POs and executes the HOOK POINTs
- */
-static void scan_decode(u_char *param, const struct pcap_pkthdr *pkthdr, const u_char *pkt)
-{
-   FUNC_DECODER_PTR(packet_decoder);
-   struct packet_object po;
-   bpf_u_int32 len;
-   u_char *data;
-   bpf_u_int32 datalen;
-
-   CANCELLATION_POINT();
-
-   /* extract data and datalen from pcap packet */
-   data = (u_char *)pkt;
-   datalen = pkthdr->caplen;
-
-   /* alloc the packet object structure to be passet through decoders */
-   packet_create_object(&po, data, datalen);
-
-   /* set the po timestamp */
-   memcpy(&po.ts, &pkthdr->ts, sizeof(struct timeval));
-
-   /*
-    * in this special parsing, the packet must be ignored by
-    * application layer, leave this untouched.
-    */
-   po.flags |= PO_DONT_DISSECT;
-
-   /*
-    * start the analysis through the decoders stack
-    * after this fuction the packet is completed (all flags set)
-    */
-   packet_decoder = get_decoder(LINK_LAYER, GBL_PCAP->dlt);
-   BUG_IF(packet_decoder == NULL);
-   packet_decoder(data, datalen, &len, &po);
-
-   /* free the structure */
-   packet_destroy_object(&po);
-
-   CANCELLATION_POINT();
-
-   return;
-}
-
-
-/*
- * receives the ARP packets
+ * receives the ARP and ICMPv6 ND packets 
  */
 static void get_response(struct packet_object *po)
 {
    struct ip_list *t;
+   char tmp[MAX_ASCII_ADDR_LEN];
+
+   DEBUG_MSG("get_response from %s", ip_addr_ntoa(&po->L3.src, tmp));
 
    /* if at least one target is the whole netmask, add the entry */
    if (GBL_TARGET1->scan_all || GBL_TARGET2->scan_all) {
@@ -346,7 +327,7 @@ static void get_response(struct packet_object *po)
       return;
    }
 
-   /* else only add arp replies within the targets */
+   /* else only add arp and icmp6 replies within the targets */
 
    /* search in target 1 */
    LIST_FOREACH(t, &GBL_TARGET1->ips, next)
@@ -361,13 +342,30 @@ static void get_response(struct packet_object *po)
          add_host(&po->L3.src, po->L2.src, NULL);
          return;
       }
+
+#ifdef WITH_IPV6
+   /* same for IPv6 */
+   /* search in target 1 */
+   LIST_FOREACH(t, &GBL_TARGET1->ip6, next)
+      if (!ip_addr_cmp(&t->ip, &po->L3.src)) {
+         return;
+      }
+
+   /* search in target 2 */
+   LIST_FOREACH(t, &GBL_TARGET2->ip6, next)
+      if (!ip_addr_cmp(&t->ip, &po->L3.src)) {
+         add_host(&po->L3.src, po->L2.src, NULL);
+         return;
+      }
+#endif
+
 }
 
 
 /*
  * scan the netmask to find all hosts
  */
-static void scan_netmask(pthread_t pid)
+static void scan_netmask(void)
 {
    u_int32 netmask, current, myip;
    int nhosts, i, ret;
@@ -375,14 +373,8 @@ static void scan_netmask(pthread_t pid)
    struct ip_list *e, *tmp;
    char title[100];
 
-#if !defined(OS_WINDOWS)
-   struct timespec tm;
-   tm.tv_nsec = GBL_CONF->arp_storm_delay * 1000;
-   tm.tv_sec = 0;
-#endif
-
-   netmask = ip_addr_to_int32(&GBL_IFACE->netmask.addr);
-   myip = ip_addr_to_int32(&GBL_IFACE->ip.addr);
+   netmask = *GBL_IFACE->netmask.addr32;
+   myip = *GBL_IFACE->ip.addr32;
 
    /* the number of hosts in this netmask */
    nhosts = ntohl(~netmask);
@@ -422,24 +414,23 @@ static void scan_netmask(pthread_t pid)
       /* user has requested to stop the task */
       if (ret == UI_PROGRESS_INTERRUPTED) {
          INSTANT_USER_MSG("Scan interrupted by user. Partial results may have been recorded...\n");
-         /* destroy the capture thread and remove the hook function */
-         ec_thread_destroy(pid);
+         /* stop the capture thread if sniffing is not active */
+         if (!GBL_SNIFF->active)
+            capture_stop(GBL_IFACE);
+
          hook_del(HOOK_PACKET_ARP, &get_response);
          /* delete the temporary list */
          LIST_FOREACH_SAFE(e, &ip_list_head, next, tmp) {
             LIST_REMOVE(e, next);
             SAFE_FREE(e);
          }
+         SCAN_UNLOCK;
          /* cancel the scan thread */
          ec_thread_exit();
       }
 
       /* wait for a delay */
-#if defined(OS_WINDOWS)
-      usleep(GBL_CONF->arp_storm_delay * 1000);
-#else
-      nanosleep(&tm, NULL);
-#endif
+      ec_usleep(MILLI2MICRO(GBL_CONF->arp_storm_delay));
 
    }
 
@@ -453,10 +444,73 @@ static void scan_netmask(pthread_t pid)
 }
 
 
+#ifdef WITH_IPV6
+/*
+ * probe active IPv6 hosts
+ */
+static void scan_ip6_onlink(void)
+{
+   int ret, i = 0;
+   struct net_list *e;
+   struct ip_addr an;
+   char title[100];
+
+   ip_addr_init(&an, AF_INET6, (u_char *)IP6_ALL_NODES);
+
+   snprintf(title, sizeof(title)-1, "Probing %d seconds for active IPv6 nodes ...", GBL_CONF->icmp6_probe_delay);
+   INSTANT_USER_MSG("%s\n", title);
+
+   DEBUG_MSG("scan_ip6_onlink: ");
+
+   /* go through the list of IPv6 addresses on the selected interface */
+   LIST_FOREACH(e, &GBL_IFACE->ip6_list, next) {
+      /*
+       * ping to all-nodes from all ip addresses to get responses from all 
+       * IPv6 networks (global, link-local, ...)
+       */
+      send_icmp6_echo(&e->ip, &an);
+
+#if EC_CHECK_LIBNET_VERSION(1,2)
+      /*
+       * sending this special icmp probe motivates hosts to respond with a icmp 
+       * error message even if they are configured not to respond to icmp requests.
+       * since libnet < 1.2 has a bug when sending IPv6 option headers
+       * we can only use this type of probe if we have at least libnet 1.2 or above
+       */
+      send_icmp6_echo_opt(&e->ip, &an, IP6_DSTOPT_UNKN, sizeof(IP6_DSTOPT_UNKN));
+#endif
+   }
+
+   for (i=0; i<=GBL_CONF->icmp6_probe_delay * 1000; i++) {
+      /* update the progress bar */
+      ret = ui_progress(title, i, GBL_CONF->icmp6_probe_delay * 1000);
+
+      /* user has requested to stop the task */
+      if (ret == UI_PROGRESS_INTERRUPTED) {
+         INSTANT_USER_MSG("Scan interrupted by user. Partial results may have been recorded...\n");
+         /* stop the capture thread if sniffing is not active */
+         if (!GBL_SNIFF->active)
+            capture_stop(GBL_IFACE);
+
+         hook_del(HOOK_PACKET_ICMP6_NADV, &get_response);
+         hook_del(HOOK_PACKET_ICMP6_RPLY, &get_response);
+         hook_del(HOOK_PACKET_ICMP6_PARM, &get_response);
+         SCAN_UNLOCK;
+         /* cancel the scan thread */
+         ec_thread_exit();
+      }
+      /* wait for a delay */
+      ec_usleep(MILLI2MICRO(1)); // 1ms
+   }
+   
+}
+#endif
+
+
 /*
  * scan only the target hosts
  */
-static void scan_targets(pthread_t pid)
+static void scan_targets(void)
 {
    int nhosts = 0, found, n = 1, ret;
    struct ip_list *e, *i, *m, *tmp;
@@ -464,13 +518,7 @@ static void scan_targets(pthread_t pid)
 
 #ifdef WITH_IPV6
    struct ip_addr ip;
-   struct ip_addr bc;
-#endif
-
-#if !defined(OS_WINDOWS)
-   struct timespec tm;
-   tm.tv_nsec = GBL_CONF->arp_storm_delay * 1000;
-   tm.tv_sec = 0;
+   struct ip_addr sn;
 #endif
 
    DEBUG_MSG("scan_targets: merging targets...");
@@ -492,6 +540,7 @@ static void scan_targets(pthread_t pid)
       /* add to the list randomly */
       random_list(e, nhosts);
    }
+#ifdef WITH_IPV6
    LIST_FOREACH(i, &GBL_TARGET1->ip6, next) {
 
       SAFE_CALLOC(e, 1, sizeof(struct ip_list));
@@ -500,6 +549,7 @@ static void scan_targets(pthread_t pid)
 
       random_list(e, nhosts);
    }
+#endif
 
    /* then merge the target2 ips */
    LIST_FOREACH(i, &GBL_TARGET2->ips, next) {
@@ -524,6 +574,7 @@ static void scan_targets(pthread_t pid)
       }
    }
 
+#ifdef WITH_IPV6
    LIST_FOREACH(i, &GBL_TARGET2->ip6, next) {
       found = 0;
 
@@ -542,6 +593,7 @@ static void scan_targets(pthread_t pid)
          random_list(e, nhosts);
       }
    }
+#endif
 
 
    DEBUG_MSG("scan_targets: %d hosts to be scanned", nhosts);
@@ -562,9 +614,10 @@ static void scan_targets(pthread_t pid)
             break;
 #ifdef WITH_IPV6
          case AF_INET6:
-            ip_addr_is_local(&e->ip, &ip);
-            ip_addr_init(&bc, AF_INET6, (u_char*)IP6_ALL_NODES);
-            send_icmp6_nsol(&ip, &bc, &e->ip, GBL_IFACE->mac);
+            if (ip_addr_is_local(&e->ip, &ip) == E_SUCCESS) {
+               ip_addr_init_sol(&sn, &e->ip);
+               send_icmp6_nsol(&ip, &sn, &e->ip, GBL_IFACE->mac);
+            }
             break;
 #endif
       }
@@ -575,25 +628,28 @@ static void scan_targets(pthread_t pid)
       /* user has requested to stop the task */
       if (ret == UI_PROGRESS_INTERRUPTED) {
          INSTANT_USER_MSG("Scan interrupted by user. Partial results may have been recorded...\n");
-         /* destroy the capture thread and remove the hook function */
-         ec_thread_destroy(pid);
+         /* stop the capture thread if sniffing is not active */
+         if (!GBL_SNIFF->active)
+            capture_stop(GBL_IFACE);
+
          hook_del(HOOK_PACKET_ARP, &get_response);
+#ifdef WITH_IPV6
          hook_del(HOOK_PACKET_ICMP6_NADV, &get_response);
+         hook_del(HOOK_PACKET_ICMP6_RPLY, &get_response);
+         hook_del(HOOK_PACKET_ICMP6_PARM, &get_response);
+#endif
          /* delete the temporary list */
          LIST_FOREACH_SAFE(e, &ip_list_head, next, tmp) {
             LIST_REMOVE(e, next);
             SAFE_FREE(e);
          }
+         SCAN_UNLOCK;
          /* cancel the scan thread */
          ec_thread_exit();
       }
 
       /* wait for a delay */
-#if defined(OS_WINDOWS)
-      usleep(GBL_CONF->arp_storm_delay * 100);
-#else
-      nanosleep(&tm, NULL);
-#endif
+      ec_usleep(MILLI2MICRO(GBL_CONF->arp_storm_delay));
 
    }
 
@@ -615,7 +671,10 @@ int scan_load_hosts(char *filename)
    char ip[MAX_ASCII_ADDR_LEN];
    char mac[ETH_ASCII_ADDR_LEN];
    char name[MAX_HOSTNAME_LEN];
-   u_int8 tip[MAX_IP_ADDR_LEN];
+   struct in_addr ipaddr;
+#ifdef WITH_IPV6
+   struct in6_addr ip6addr;
+#endif
    struct ip_addr hip;
    u_int8 hmac[MEDIA_ADDR_LEN];
 
@@ -628,25 +687,33 @@ int scan_load_hosts(char *filename)
 
    INSTANT_USER_MSG("Loading hosts list from file %s\n", filename);
 
-   /* XXX - adapt to IPv6 */
    /* read the file */
    for (nhosts = 0; !feof(hf); nhosts++) {
-      int proto;
 
       if (fscanf(hf, "%"EC_TOSTRING(MAX_ASCII_ADDR_LEN)"s %"EC_TOSTRING(ETH_ASCII_ADDR_LEN)"s %"EC_TOSTRING(MAX_HOSTNAME_LEN)"s\n", ip, mac, name) != 3 ||
          *ip == '#' || *mac == '#' || *name == '#')
          continue;
 
       /* convert to network */
-      mac_addr_aton(mac, hmac);
-
-      proto = (strchr(ip, ':')) ? AF_INET6 : AF_INET;
-      if (!inet_pton(proto, ip, tip)) {
-         del_hosts_list();
-         SEMIFATAL_ERROR("Bad parsing on line %d", nhosts + 1);
+      if (!mac_addr_aton(mac, hmac)) {
+         USER_MSG("Bad MAC address while parsing line %d", nhosts + 1);
+         continue;
       }
 
-      ip_addr_init(&hip, proto, (u_char *)tip);
+      if (inet_pton(AF_INET, ip, &ipaddr) == 1) { /* is IPv4 address*/
+         ip_addr_init(&hip, AF_INET, (u_char *)&ipaddr);
+      }
+#ifdef WITH_IPV6
+      else if (inet_pton(AF_INET6, ip, &ip6addr) == 1) { /* is IPv6 address */
+         ip_addr_init(&hip, AF_INET6, (u_char *)&ip6addr);
+      }
+#endif
+      else { /* neither IPv4 nor IPv6 - inform user and skip line*/
+         USER_MSG("Bad IP address while parsing line %d", nhosts + 1);
+         continue;
+         //del_hosts_list();
+         //SEMIFATAL_ERROR("Bad parsing on line %d", nhosts + 1);
+      }
 
       /* wipe the null hostname */
       if (!strcmp(name, "-"))
@@ -660,7 +727,7 @@ int scan_load_hosts(char *filename)
 
    DEBUG_MSG("scan_load_hosts: loaded %d hosts lines", nhosts);
 
-   return ESUCCESS;
+   return E_SUCCESS;
 }
 
 
@@ -697,7 +764,7 @@ int scan_save_hosts(char *filename)
 
    INSTANT_USER_MSG("%d hosts saved to file %s\n", nhosts, filename);
 
-   return ESUCCESS;
+   return E_SUCCESS;
 }
 
 
@@ -709,6 +776,14 @@ void add_host(struct ip_addr *ip, u_int8 mac[MEDIA_ADDR_LEN], char *name)
 {
    struct hosts_list *hl, *h;
 
+   /* don't add to hostlist if the found IP is ours */
+   if (ip_addr_is_ours(ip) == E_FOUND) 
+      return;
+
+   /* don't add undefined address */
+   if (ip_addr_is_zero(ip))
+      return;
+
    SAFE_CALLOC(h, 1, sizeof(struct hosts_list));
 
    /* fill the struct */
@@ -796,12 +871,12 @@ void __init hook_init(void)
 static void hosts_list_hook(struct packet_object *po)
 {
    switch(ip_addr_is_ours(&po->L3.src)) {
-      case EFOUND:
-      case EBRIDGE:
+      case E_FOUND:
+      case E_BRIDGE:
          return;
    }
 
-   if(ip_addr_is_local(&po->L3.src, NULL) == ESUCCESS) {
+   if(ip_addr_is_local(&po->L3.src, NULL) == E_SUCCESS) {
       add_host(&po->L3.src, po->L2.src, NULL);
    }
 
