@@ -48,17 +48,7 @@ static pthread_cond_t init_cond = PTHREAD_COND_INITIALIZER;
 
 /* protos... */
 
-char * ec_thread_getname(pthread_t id);
-pthread_t ec_thread_getpid(char *name);
-char * ec_thread_getdesc(pthread_t id);
-void ec_thread_register_detached(pthread_t id, char *name, char *desc, int detached);
-void ec_thread_register(pthread_t id, char *name, char *desc);
-pthread_t ec_thread_new(char *name, char *desc, void *(*function)(void *), void *args);
 pthread_t ec_thread_detached(char *name, char *desc, void *(*function)(void *), void *args, int detached);
-void ec_thread_destroy(pthread_t id);
-void ec_thread_init(void);
-void ec_thread_kill_all(void);
-void ec_thread_exit(void);
 
 /*******************************************/
 
@@ -96,7 +86,7 @@ char * ec_thread_getname(pthread_t id)
 
 /* 
  * returns the pid of a thread 
- * ZERO if not found !! (take care, not -ENOTFOUND !)
+ * ZERO if not found !! (take care, not -E_NOTFOUND !)
  */
 
 pthread_t ec_thread_getpid(char *name)
@@ -319,8 +309,8 @@ void ec_thread_kill_all(void)
 
 #ifdef OS_WINDOWS
    /* prevent hanging UI. Not sure how this works, but it does... */
-   if (GBL_PCAP->pcap)
-      ec_win_pcap_stop(GBL_PCAP->pcap);
+   if (GBL_IFACE->pcap)
+      ec_win_pcap_stop(GBL_IFACE->pcap);
 #endif
    
    LIST_FOREACH_SAFE(current, &thread_list_head, next, old) {
