@@ -52,7 +52,7 @@ static void curses_connection_kill_wrapper(void);
 static void curses_connection_inject(void);
 static void inject_user(void);
 static void curses_connection_inject_file(void);
-static void inject_file(char *path, char *file);
+static void inject_file(const char *path, char *file);
 static void curses_connection_help(void *dummy);
 static void curses_connection_data_help(void);
 
@@ -124,6 +124,9 @@ static void curses_kill_connections(void)
 
 static void curses_connection_help(void *dummy)
 {
+   /* variable not used */
+   (void) dummy;
+
    char help[] = "HELP: shortcut list:\n\n"
                  "  ENTER - open the data panel in real time\n"
                  "    d   - show details of the current connection\n"
@@ -181,11 +184,11 @@ static void curses_connection_detail(void *conn)
    wdg_window_print(wdg_conn_detail, 1, 2, "Destination MAC address :  %s", mac_addr_ntoa(c->co->L2_addr2, tmp));
    
    wdg_window_print(wdg_conn_detail, 1, 4, "Source IP address       :  %s", ip_addr_ntoa(&(c->co->L3_addr1), tmp));
-   if (host_iptoa(&(c->co->L3_addr1), name) == ESUCCESS)
+   if (host_iptoa(&(c->co->L3_addr1), name) == E_SUCCESS)
       wdg_window_print(wdg_conn_detail, 1, 5, "                           %s", name);
    
    wdg_window_print(wdg_conn_detail, 1, 6, "Destination IP address  :  %s", ip_addr_ntoa(&(c->co->L3_addr2), tmp));
-   if (host_iptoa(&(c->co->L3_addr2), name) == ESUCCESS)
+   if (host_iptoa(&(c->co->L3_addr2), name) == E_SUCCESS)
       wdg_window_print(wdg_conn_detail, 1, 7, "                           %s", name);
    
    switch (c->co->L4_proto) {
@@ -513,12 +516,12 @@ static void curses_connection_kill(void *conn)
   
    /* kill it */
    switch (user_kill(c->co)) {
-      case ESUCCESS:
+      case E_SUCCESS:
          /* set the status */
          c->co->status = CONN_KILLED;
          curses_message("The connection was killed !!");
          break;
-      case -EFATAL:
+      case -E_FATAL:
          curses_message("Cannot kill UDP connections !!");
          break;
    }
@@ -530,6 +533,9 @@ static void curses_connection_kill(void *conn)
  */
 static void curses_connection_purge(void *conn)
 {
+   /* variable not used */
+   (void) conn;
+
    DEBUG_MSG("curses_connection_purge");
    
    conntrack_purge();
@@ -621,7 +627,7 @@ static void curses_connection_inject_file(void)
 /*
  * map the file into memory and pass the buffer to the inject function
  */
-static void inject_file(char *path, char *file)
+static void inject_file(const char *path, char *file)
 {
    char *filename;
    int fd;
