@@ -22,10 +22,17 @@
 #include <wdg.h>
 
 #include <ncurses.h>
+#include <pthread.h>
 
 
 /* GLOBALS */
 
+/* mutexes */
+static pthread_mutex_t wdg_mutex = PTHREAD_MUTEX_INITIALIZER;
+#define WDG_LOCK do { pthread_mutex_lock(&wdg_mutex); } while (0)
+#define WDG_UNLOCK do { pthread_mutex_unlock(&wdg_mutex); } while (0)
+
+
 /* information about the current screen */
 struct wdg_scr current_screen;
 
@@ -54,37 +61,10 @@ static int wdg_exit_key;
 
 /* PROTOS */
 
-void wdg_init(void);
-void wdg_cleanup(void);
-void wdg_exit(void);
-void wdg_update_screen(void);
-void wdg_redraw_all(void);
-
-void wdg_add_idle_callback(void (*callback)(void));
-void wdg_del_idle_callback(void (*callback)(void));
-
-int wdg_events_handler(int exit_key);
 static void wdg_dispatch_msg(int key, struct wdg_mouse_event *mouse);
 static void wdg_switch_focus(int type);
 #define SWITCH_FOREWARD 1
 #define SWITCH_BACKWARD 2
-void wdg_set_focus(struct wdg_object *wo);
-
-int wdg_create_object(struct wdg_object **wo, size_t type, size_t flags);
-int wdg_destroy_object(struct wdg_object **wo);
-void wdg_add_destroy_key(struct wdg_object *wo, int key, void (*callback)(void));
-
-void wdg_set_size(struct wdg_object *wo, int x1, int y1, int x2, int y2);
-void wdg_draw_object(struct wdg_object *wo);
-size_t wdg_get_type(struct wdg_object *wo);
-void wdg_init_color(u_char pair, u_char fg, u_char bg);
-void wdg_set_color(wdg_t *wo, size_t part, u_char pair);
-void wdg_screen_color(u_char pair);
-
-size_t wdg_get_nlines(struct wdg_object *wo);
-size_t wdg_get_ncols(struct wdg_object *wo);
-size_t wdg_get_begin_x(struct wdg_object *wo);
-size_t wdg_get_begin_y(struct wdg_object *wo);
 
 /* creation function from other widgets */
 extern void wdg_create_compound(struct wdg_object *wo);
@@ -217,7 +197,9 @@ void wdg_exit(void)
  */
 void wdg_update_screen(void)
 {
+   WDG_LOCK;
    doupdate();
+   WDG_UNLOCK;
 }
 
 /* 
@@ -267,7 +249,9 @@ int wdg_events_handler(int exit_key)
             /* switch focus between objects */
             wdg_switch_focus(SWITCH_FOREWARD);
             /* update the screen */
+            WDG_LOCK;
             doupdate();
+            WDG_UNLOCK;
             break;
 
          case KEY_CTRL_L:
@@ -276,7 +260,9 @@ int wdg_events_handler(int exit_key)
             /* the screen has been resized */
             wdg_redraw_all();
             /* update the screen */
+            WDG_LOCK;
             doupdate();
+            WDG_UNLOCK;
             break;
             
          case ERR:
@@ -299,13 +285,15 @@ int wdg_events_handler(int exit_key)
              * update the screen.
              * all the function uses wnoutrefresh() funcions 
              */
+            WDG_LOCK;
             doupdate();
+            WDG_UNLOCK;
             break;
             
          default:
             /* emergency exit key */
             if (key == wdg_exit_key)
-               return WDG_ESUCCESS;
+               return WDG_E_SUCCESS;
 
 #ifdef NCURSES_MOUSE_VERSION
             /* handle mouse events */
@@ -325,14 +313,16 @@ int wdg_events_handler(int exit_key)
             /* dispatch the user input */
             wdg_dispatch_msg(key, &mouse);
             /* update the screen */
+            WDG_LOCK;
             doupdate();
+            WDG_UNLOCK;
             break;
       }
    }
    
    /* NOT REACHED */
    
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /*
@@ -414,7 +404,7 @@ static void wdg_dispatch_msg(int key, struct wdg_mouse_event *mouse)
        * other objects and needs to get the event first
        */
       if (wdg_root_obj != NULL) {
-         if (wdg_root_obj->get_msg(wdg_root_obj, key, mouse) == WDG_ESUCCESS)
+         if (wdg_root_obj->get_msg(wdg_root_obj, key, mouse) == WDG_E_SUCCESS)
             /* the root object handled the message */
             return;
       }
@@ -425,7 +415,7 @@ static void wdg_dispatch_msg(int key, struct wdg_mouse_event *mouse)
        * to prevent an undesired raising of underlaying objects
        */
       if (wdg_focused_obj != NULL) {
-         if (wdg_focused_obj->wo->get_msg(wdg_focused_obj->wo, key, mouse) == WDG_ESUCCESS)
+         if (wdg_focused_obj->wo->get_msg(wdg_focused_obj->wo, key, mouse) == WDG_E_SUCCESS)
             /* the focused object handled the message */
             return;     
       }
@@ -433,7 +423,7 @@ static void wdg_dispatch_msg(int key, struct wdg_mouse_event *mouse)
       /* dispatch to all the other objects */
       TAILQ_FOREACH(wl, &wdg_objects_list, next) {
          if ((wl->wo->flags & WDG_OBJ_WANT_FOCUS) && (wl->wo->flags & WDG_OBJ_VISIBLE) ) {
-            if (wl->wo->get_msg(wl->wo, key, mouse) == WDG_ESUCCESS)
+            if (wl->wo->get_msg(wl->wo, key, mouse) == WDG_E_SUCCESS)
                return;
          }
       }
@@ -443,7 +433,7 @@ static void wdg_dispatch_msg(int key, struct wdg_mouse_event *mouse)
 
       /* first dispatch to the root object */
       if (wdg_root_obj != NULL) {
-         if (wdg_root_obj->get_msg(wdg_root_obj, key, mouse) == WDG_ESUCCESS)
+         if (wdg_root_obj->get_msg(wdg_root_obj, key, mouse) == WDG_E_SUCCESS)
             /* the root object handled the message */
             return;
          
@@ -461,7 +451,7 @@ static void wdg_dispatch_msg(int key, struct wdg_mouse_event *mouse)
        * dispatch to the focused one
        */
       if (wdg_focused_obj != NULL) {
-         if (wdg_focused_obj->wo->get_msg(wdg_focused_obj->wo, key, mouse) == WDG_ESUCCESS)
+         if (wdg_focused_obj->wo->get_msg(wdg_focused_obj->wo, key, mouse) == WDG_E_SUCCESS)
             /* the focused object handled the message */
             return;      
          
@@ -628,7 +618,7 @@ int wdg_create_object(struct wdg_object **wo, size_t type, size_t flags)
          
       default:
          WDG_SAFE_FREE(*wo);
-         return -WDG_EFATAL;
+         return -WDG_E_FATAL;
          break;
    }
    
@@ -645,7 +635,7 @@ int wdg_create_object(struct wdg_object **wo, size_t type, size_t flags)
    if (flags & WDG_OBJ_ROOT_OBJECT)
       wdg_root_obj = *wo;
    
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /*
@@ -659,7 +649,7 @@ int wdg_destroy_object(struct wdg_object **wo)
   
    /* sanity check */
    if (*wo == NULL)
-      return -WDG_ENOTHANDLED;
+      return -WDG_E_NOTHANDLED;
   
    /* delete it from the obj_list */
    TAILQ_FOREACH(wl, &wdg_objects_list, next) {
@@ -697,11 +687,11 @@ int wdg_destroy_object(struct wdg_object **wo)
          /* then free the object */
          WDG_SAFE_FREE(*wo);
          
-         return WDG_ESUCCESS;
+         return WDG_E_SUCCESS;
       }
    }
 
-   return -WDG_ENOTHANDLED;
+   return -WDG_E_NOTHANDLED;
 }
 
 /*
