@@ -47,8 +47,6 @@ static int wdg_panel_get_msg(struct wdg_object *wo, int key, struct wdg_mouse_ev
 
 static void wdg_panel_border(struct wdg_object *wo);
 
-void wdg_panel_print(wdg_t *wo, size_t x, size_t y, char *fmt, ...);
-
 /*******************************************/
 
 /* 
@@ -98,7 +96,7 @@ static int wdg_panel_destroy(struct wdg_object *wo)
 
    WDG_SAFE_FREE(wo->extend);
 
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -108,7 +106,7 @@ static int wdg_panel_resize(struct wdg_object *wo)
 {
    wdg_panel_redraw(wo);
 
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -155,14 +153,14 @@ static int wdg_panel_redraw(struct wdg_object *wo)
 
       /* create the outher window */
       if ((ww->win = new_panel(newwin(l, c, y, x))) == NULL)
-         return -WDG_EFATAL;
+         return -WDG_E_FATAL;
 
       /* draw the borders */
       wdg_panel_border(wo);
 
       /* create the inner (actual) window */
       if ((ww->sub = new_panel(newwin(l - 2, c - 2, y + 1, x + 1))) == NULL)
-         return -WDG_EFATAL;
+         return -WDG_E_FATAL;
       
       /* set the window color */
       wbkgd(W(ww->sub), COLOR_PAIR(wo->window_color));
@@ -182,7 +180,7 @@ static int wdg_panel_redraw(struct wdg_object *wo)
    
    wo->flags |= WDG_OBJ_VISIBLE;
 
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -196,7 +194,7 @@ static int wdg_panel_get_focus(struct wdg_object *wo)
    /* redraw the window */
    wdg_panel_redraw(wo);
    
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -210,7 +208,7 @@ static int wdg_panel_lost_focus(struct wdg_object *wo)
    /* redraw the window */
    wdg_panel_redraw(wo);
    
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -226,16 +224,16 @@ static int wdg_panel_get_msg(struct wdg_object *wo, int key, struct wdg_mouse_ev
          if (wenclose(W(ww->win), mouse->y, mouse->x))
             wdg_set_focus(wo);
          else 
-            return -WDG_ENOTHANDLED;
+            return -WDG_E_NOTHANDLED;
          break;
 
       /* message not handled */
       default:
-         return -WDG_ENOTHANDLED;
+         return -WDG_E_NOTHANDLED;
          break;
    }
   
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /*
