@@ -102,11 +102,7 @@ void gtkui_select_protocol(void)
    frame = gtk_frame_new("Select the protocol");
    gtk_container_add(GTK_CONTAINER(content), frame);
 
-#if GTK_CHECK_VERSION(3, 0, 0)
-   hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 10);
-#else
-   hbox = gtk_hbox_new(FALSE, 10);
-#endif
+   hbox = gtkui_box_new(GTK_ORIENTATION_HORIZONTAL, 10, FALSE);
    gtk_container_add(GTK_CONTAINER(frame), hbox);
 
    radio = gtk_radio_button_new_with_mnemonic(NULL, "a_ll");
@@ -409,19 +405,11 @@ void gtkui_current_targets(void)
 
    targets_window = gtkui_page_new("Targets", &gtkui_targets_destroy, &gtkui_targets_detach);
 
-#if GTK_CHECK_VERSION(3, 0, 0)
-   vbox = gtk_box_new(GTK_ORIENTATION_VERTICAL, 0);
-#else
-   vbox = gtk_vbox_new(FALSE, 0);
-#endif
+   vbox= gtkui_box_new(GTK_ORIENTATION_VERTICAL, 0, FALSE);
    gtk_container_add(GTK_CONTAINER (targets_window), vbox);
    gtk_widget_show(vbox);
 
-#if GTK_CHECK_VERSION(3, 0, 0)
-   hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5);
-#else
-   hbox = gtk_hbox_new(TRUE, 5);
-#endif
+   hbox = gtkui_box_new(GTK_ORIENTATION_HORIZONTAL, 5, TRUE);
    gtk_box_pack_start(GTK_BOX(vbox), hbox, TRUE, TRUE, 0);
    gtk_widget_show(hbox);
 
@@ -466,11 +454,7 @@ void gtkui_current_targets(void)
    gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
    /* buttons */
-#if GTK_CHECK_VERSION(3, 0, 0)
-   hbox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, 5);
-#else
-   hbox = gtk_hbox_new(TRUE, 5);
-#endif
+   hbox = gtkui_box_new(GTK_ORIENTATION_HORIZONTAL, 5, TRUE);
    gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 0);
 
    button = gtk_button_new_with_mnemonic("Delete");
