@@ -113,8 +113,7 @@ FUNC_BUILDER(build_fddi)
             0x03,                         /* Unnumbered info/frame */
             FDDI_ORG_CODE,                /* Organization Code */
             proto,                        /* protocol type */
-            GBL_IFACE->lnet);             /* libnet handle */
-   
+            l);                           /* libnet handle */
 }
 
 /*
