@@ -3,12 +3,12 @@
 
     Copyright (C) ALoR & NaGA
 
-    This program is free software; you can redfopibute it and/or modify
+    This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation; either version 2 of the License, or
     (at your option) any later version.
 
-    This program is dfopibuted in the hope that it will be useful,
+    This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
@@ -58,7 +58,7 @@ void test_filter(char *filename)
    /*memset(fenv, 0, sizeof(struct filter_env));*/
    
    /* load the file */
-   if (filter_load_file(filename, &flist, 1) != ESUCCESS) {
+   if (filter_load_file(filename, &flist, 1) != E_SUCCESS) {
       exit(-1);
    }
    fenv = &flist->env;
@@ -235,6 +235,11 @@ void print_function(struct filter_op *fop, u_int32 eip)
                fop->op.func.string);
          break;
          
+      case FFUNC_EXECINJECT:
+         fprintf(stdout, "%04lu: EXECINJECT \"%s\"\n", (unsigned long)eip, 
+               fop->op.func.string);
+         break;
+         
       case FFUNC_LOG:
          fprintf(stdout, "%04lu: LOG to \"%s\"\n", (unsigned long)eip, fop->op.func.string);
          break;
